Module usb

Module usb 

Structs

DfuFunctionalDescriptor
Structure of the DFU-class functional descriptor.
GenericDescriptorRef
InterfaceClass
Simple newtype struct for some clarity in function arguments and whatnot.
InterfaceProtocol
Simple newtype struct for some clarity in function arguments and whatnot.
InterfaceSubClass
Simple newtype struct for some clarity in function arguments and whatnot.
Pid
Simple newtype struct for some clarity in function arguments and whatnot.
PortId
Vid
Simple newtype struct for some clarity in function arguments and whatnot.

Enums

DescriptorConvertError
DfuOperatingMode
Enum representing the two “modes” a DFU-class device can be in.
DfuRequest
Enum of request numbers for DFU class requests.