Structs
- DfuFunctional
Descriptor - Structure of the DFU-class functional descriptor.
- Generic
Descriptor Ref - Interface
Class - Simple newtype struct for some clarity in function arguments and whatnot.
- Interface
Protocol - Simple newtype struct for some clarity in function arguments and whatnot.
- Interface
SubClass - Simple newtype struct for some clarity in function arguments and whatnot.
- Pid
- Simple newtype struct for some clarity in function arguments and whatnot.
- PortId
- Vid
- Simple newtype struct for some clarity in function arguments and whatnot.
Enums
- Descriptor
Convert Error - DfuOperating
Mode - Enum representing the two “modes” a DFU-class device can be in.
- DfuRequest
- Enum of request numbers for DFU class requests.